@@ -1,21 +1,9 @@
 /*
- * Copyright © 2016-2019 Red Hat, Inc
+ * SPDX-FileCopyrightText: 2016-2019 Red Hat Inc
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *       Jan Grulich <jgrulich@redhat.com>
+ * SPDX-FileCopyrightText: 2016-2018 Jan Grulich <jgrulich@redhat.com>
  */
 
 #ifndef XDG_DESKTOP_PORTAL_KDE_APPCHOOSER_DIALOG_H
@@ -36,7 +24,7 @@ class ApplicationItem
 public:
     enum ApplicationCategory {
         PreferredApplication,
-        AllApplications
+        AllApplications,
     };
 
     explicit ApplicationItem(const QString &name, const QString &icon, const QString &desktopFileName);
@@ -49,6 +37,7 @@ public:
     ApplicationCategory applicationCategory() const;
 
     bool operator==(const ApplicationItem &item) const;
+
 private:
     QString m_applicationName;
     QString m_applicationIcon;
@@ -85,7 +74,8 @@ private:
     QString m_filter;
 };
 
-class AppChooserData : public QObject {
+class AppChooserData : public QObject
+{
     Q_OBJECT
     Q_PROPERTY(QString fileName READ fileName WRITE setFileName NOTIFY fileNameChanged)
     Q_PROPERTY(QString defaultApp READ defaultApp WRITE setDefaultApp NOTIFY defaultAppChanged)
@@ -117,7 +107,7 @@ public:
         ApplicationNameRole = Qt::UserRole + 1,
         ApplicationIconRole,
         ApplicationDesktopFileRole,
-        ApplicationCategoryRole
+        ApplicationCategoryRole,
     };
 
     explicit AppModel(QObject *parent = nullptr);
@@ -139,8 +129,12 @@ class AppChooserDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit AppChooserDialog(const QStringList &choices, const QString &defaultApp, const QString &fileName,
-                              const QString &mimeName = QString(), QDialog *parent = nullptr, Qt::WindowFlags flags = {});
+    explicit AppChooserDialog(const QStringList &choices,
+                              const QString &defaultApp,
+                              const QString &fileName,
+                              const QString &mimeName = QString(),
+                              QDialog *parent = nullptr,
+                              Qt::WindowFlags flags = {});
     ~AppChooserDialog();
 
     void updateChoices(const QStringList &choices);
