@@ -13,6 +13,7 @@
 
 #include <QDBusArgument>
 #include <QDBusMetaType>
+#include <QGuiApplication>
 
 #include <KNotification>
 #include <QEventLoop>
@@ -28,12 +29,14 @@
 #include <KWayland/Client/connection_thread.h>
 #include <KWayland/Client/event_queue.h>
 #include <KWayland/Client/plasmawindowmanagement.h>
+#include <KWayland/Client/plasmawindowmodel.h>
 #include <KWayland/Client/registry.h>
 
 // system
 #include <fcntl.h>
 #include <unistd.h>
 
+#include <KStatusNotifierItem>
 #include <KWayland/Client/fakeinput.h>
 
 Q_LOGGING_CATEGORY(XdgDesktopPortalKdeWaylandIntegration, "xdp-kde-wayland-integration")
@@ -76,9 +79,9 @@ bool WaylandIntegration::startStreamingOutput(quint32 outputName, Screencasting:
     return globalWaylandIntegration->startStreamingOutput(outputName, mode);
 }
 
-bool WaylandIntegration::startStreamingWindow(const QByteArray &winid)
+bool WaylandIntegration::startStreamingWindow(const QMap<int, QVariant> &win)
 {
-    return globalWaylandIntegration->startStreamingWindow(winid);
+    return globalWaylandIntegration->startStreamingWindow(win);
 }
 
 void WaylandIntegration::stopAllStreaming()
@@ -200,8 +203,6 @@ WaylandIntegration::WaylandIntegration *WaylandIntegration::waylandIntegration()
 WaylandIntegration::WaylandIntegrationPrivate::WaylandIntegrationPrivate()
     : WaylandIntegration()
     , m_registryInitialized(false)
-    , m_connection(nullptr)
-    , m_queue(nullptr)
     , m_registry(nullptr)
     , m_fakeInput(nullptr)
     , m_screencasting(nullptr)
@@ -222,31 +223,27 @@ bool WaylandIntegration::WaylandIntegrationPrivate::isStreamingAvailable() const
     return m_screencasting;
 }
 
-void WaylandIntegration::WaylandIntegrationPrivate::bindOutput(int outputName, int outputVersion)
-{
-    KWayland::Client::Output *output = new KWayland::Client::Output(this);
-    output->setup(m_registry->bindOutput(outputName, outputVersion));
-    m_bindOutputs << output;
-}
-
 void WaylandIntegration::WaylandIntegrationPrivate::startStreamingInput()
 {
     m_streamInput = true;
 }
 
-bool WaylandIntegration::WaylandIntegrationPrivate::startStreamingWindow(const QByteArray &winid)
+bool WaylandIntegration::WaylandIntegrationPrivate::startStreamingWindow(const QMap<int, QVariant> &win)
 {
-    return startStreaming(m_screencasting->createWindowStream(QString::fromUtf8(winid), Screencasting::Hidden), {});
+    auto uuid = win[KWayland::Client::PlasmaWindowModel::Uuid].toString();
+    return startStreaming(m_screencasting->createWindowStream(uuid, Screencasting::Hidden), {}, win);
 }
 
 bool WaylandIntegration::WaylandIntegrationPrivate::startStreamingOutput(quint32 outputName, Screencasting::CursorMode mode)
 {
     auto output = m_outputMap.value(outputName).output();
 
-    return startStreaming(m_screencasting->createOutputStream(output.data(), mode), output);
+    return startStreaming(m_screencasting->createOutputStream(output.data(), mode), output, {});
 }
 
-bool WaylandIntegration::WaylandIntegrationPrivate::startStreaming(ScreencastingStream *stream, QSharedPointer<KWayland::Client::Output> output)
+bool WaylandIntegration::WaylandIntegrationPrivate::startStreaming(ScreencastingStream *stream,
+                                                                   QSharedPointer<KWayland::Client::Output> output,
+                                                                   const QMap<int, QVariant> &win)
 {
     QEventLoop loop;
     bool streamReady = false;
@@ -282,6 +279,24 @@ bool WaylandIntegration::WaylandIntegrationPrivate::startStreaming(Screencasting
             stopStreaming(nodeid);
         });
         streamReady = true;
+
+        auto item = new KStatusNotifierItem(stream);
+        item->setStandardActionsEnabled(false);
+        if (output) {
+            item->setTitle(i18n("Recording screen \"%1\"...", output->model()));
+            item->setIconByName("video-display");
+        } else {
+            auto name = win[Qt::DecorationRole].value<QIcon>().name();
+            item->setIconByName(name.isEmpty() ? "applications-all" : name);
+            item->setTitle(i18n("Recording window \"%1\"...", win[Qt::DisplayRole].toString()));
+        }
+        item->setOverlayIconByName("media-record");
+        item->setToolTip(item->iconName(), item->title(), i18n("Press to cancel"));
+        connect(item, &KStatusNotifierItem::activateRequested, stream, [=] {
+            stopStreaming(nodeid);
+            stream->deleteLater();
+        });
+
         loop.quit();
     });
     QTimer::singleShot(3000, &loop, &QEventLoop::quit);
@@ -389,41 +404,6 @@ KWayland::Client::PlasmaWindowManagement *WaylandIntegration::WaylandIntegration
     return m_windowManagement;
 }
 
-void WaylandIntegration::WaylandIntegrationPrivate::initWayland()
-{
-    m_thread = new QThread(this);
-    m_connection = new KWayland::Client::ConnectionThread;
-
-    connect(m_connection, &KWayland::Client::ConnectionThread::connected, this, &WaylandIntegrationPrivate::setupRegistry, Qt::QueuedConnection);
-    connect(m_connection, &KWayland::Client::ConnectionThread::connectionDied, this, [this] {
-        if (m_queue) {
-            delete m_queue;
-            m_queue = nullptr;
-        }
-
-        m_connection->deleteLater();
-        m_connection = nullptr;
-
-        if (m_thread) {
-            m_thread->quit();
-            if (!m_thread->wait(3000)) {
-                m_thread->terminate();
-                m_thread->wait();
-            }
-            delete m_thread;
-            m_thread = nullptr;
-        }
-    });
-    connect(m_connection, &KWayland::Client::ConnectionThread::failed, this, [this] {
-        m_thread->quit();
-        m_thread->wait();
-    });
-
-    m_thread->start();
-    m_connection->moveToThread(m_thread);
-    m_connection->initConnection();
-}
-
 void WaylandIntegration::WaylandIntegrationPrivate::addOutput(quint32 name, quint32 version)
 {
     QSharedPointer<KWayland::Client::Output> output(new KWayland::Client::Output(this));
@@ -452,10 +432,13 @@ void WaylandIntegration::WaylandIntegrationPrivate::removeOutput(quint32 name)
     qCDebug(XdgDesktopPortalKdeWaylandIntegration) << "    model: " << output.model();
 }
 
-void WaylandIntegration::WaylandIntegrationPrivate::setupRegistry()
+void WaylandIntegration::WaylandIntegrationPrivate::initWayland()
 {
-    m_queue = new KWayland::Client::EventQueue(this);
-    m_queue->setup(m_connection);
+    auto connection = KWayland::Client::ConnectionThread::fromApplication(QGuiApplication::instance());
+
+    if (!connection) {
+        return;
+    }
 
     m_registry = new KWayland::Client::Registry(this);
 
@@ -480,7 +463,6 @@ void WaylandIntegration::WaylandIntegrationPrivate::setupRegistry()
         qCDebug(XdgDesktopPortalKdeWaylandIntegration) << "Registry initialized";
     });
 
-    m_registry->create(m_connection);
-    m_registry->setEventQueue(m_queue);
+    m_registry->create(connection);
     m_registry->setup();
 }
