@@ -46,15 +46,9 @@ public:
 
     KWayland::Client::PlasmaWindowManagement *plasmaWindowManagement();
 
-protected Q_SLOTS:
-    void setupRegistry();
-
 private:
     bool m_registryInitialized = false;
 
-    QThread *m_thread = nullptr;
-    KWayland::Client::ConnectionThread *m_connection = nullptr;
-    KWayland::Client::EventQueue *m_queue = nullptr;
     KWayland::Client::Registry *m_registry = nullptr;
     KWayland::Client::PlasmaWindowManagement *m_windowManagement = nullptr;
 
@@ -75,9 +69,9 @@ public:
 
     void startStreamingInput();
 
-    bool startStreaming(ScreencastingStream *stream, QSharedPointer<KWayland::Client::Output> output);
+    bool startStreaming(ScreencastingStream *stream, QSharedPointer<KWayland::Client::Output> output, const QMap<int, QVariant> &win);
     bool startStreamingOutput(quint32 outputName, Screencasting::CursorMode mode);
-    bool startStreamingWindow(const QByteArray &winid);
+    bool startStreamingWindow(const QMap<int, QVariant> &win);
     void stopStreaming(uint32_t nodeid);
     void stopAllStreaming();
 
@@ -87,7 +81,6 @@ public:
     void requestPointerMotionAbsolute(const QPointF &pos);
     void requestPointerAxisDiscrete(Qt::Orientation axis, qreal delta);
     void requestKeyboardKeycode(int keycode, bool state);
-    void bindOutput(int outputName, int outputVersion);
 
     QMap<quint32, WaylandOutput> screens();
     QVariant streams();
@@ -107,7 +100,6 @@ private:
     QPoint m_streamedScreenPosition;
 
     QMap<quint32, WaylandOutput> m_outputMap;
-    QList<KWayland::Client::Output *> m_bindOutputs;
 
     KWayland::Client::FakeInput *m_fakeInput = nullptr;
     Screencasting *m_screencasting = nullptr;
